pub trait BinaryLikeArrayBuilder: ArrayBuilder {
// Required methods
fn type_name() -> &'static str;
fn with_capacity(capacity: usize) -> Self;
fn append_value(&mut self, value: &[u8]);
fn append_null(&mut self);
}Expand description
Trait for binary-like array builders
This trait provides unified interface for builders that append binary-like data
such as GenericBinaryBuilder<O> and crate::builder::BinaryViewBuilder
Required Methods
Sourcefn with_capacity(capacity: usize) -> Self
fn with_capacity(capacity: usize) -> Self
Creates a new builder with the given row capacity.
Sourcefn append_value(&mut self, value: &[u8])
fn append_value(&mut self, value: &[u8])
Appends a non-null string value to the builder.
Sourcefn append_null(&mut self)
fn append_null(&mut self)
Appends a null value to the builder.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".