RecordBatchStream

Trait RecordBatchStream 

pub trait RecordBatchStream: Stream<Item = Result<RecordBatch, ArrowError>> {
    // Required method
    fn schema(&self) -> &Arc<Schema> ;
}
Trait for an asynchronous stream of RecordBatches.

Required Methods

fn schema(&self) -> &Arc<Schema>

Return the schema of this RecordBatchStream.

Implementation of this trait should guarantee that all RecordBatch’s returned by this reader should have the same schema as returned from this method.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors