Struct arrow::array::PrimitiveBuilder [−][src]
pub struct PrimitiveBuilder<T: ArrowPrimitiveType> { /* fields omitted */ }
Array builder for fixed-width primitive types
Implementations
impl<T: ArrowPrimitiveType> PrimitiveBuilder<T>[src]
impl<T: ArrowPrimitiveType> PrimitiveBuilder<T>[src]pub fn new(capacity: usize) -> Self[src]
Creates a new primitive array builder
pub fn capacity(&self) -> usize[src]
Returns the capacity of this builder measured in slots of type T
pub fn append_value(&mut self, v: T::Native) -> Result<()>[src]
Appends a value of type T into the builder
pub fn append_null(&mut self) -> Result<()>[src]
Appends a null slot into the builder
pub fn append_option(&mut self, v: Option<T::Native>) -> Result<()>[src]
Appends an Option<T> into the builder
pub fn append_slice(&mut self, v: &[T::Native]) -> Result<()>[src]
Appends a slice of type T into the builder
pub fn append_values(
&mut self,
values: &[T::Native],
is_valid: &[bool]
) -> Result<()>[src]
&mut self,
values: &[T::Native],
is_valid: &[bool]
) -> Result<()>
Appends values from a slice of type T and a validity boolean slice
pub fn finish(&mut self) -> PrimitiveArray<T>[src]
Builds the PrimitiveArray and reset this builder.
pub fn finish_dict(&mut self, values: ArrayRef) -> DictionaryArray<T>[src]
Builds the DictionaryArray and reset this builder.