[][src]Module arrow::array_ops

Functions

add
divide
eq
gt
gt_eq
lt
lt_eq
max

Returns the maximum value in the array, according to the natural order.

min

Returns the minimum value in the array, according to the natural order.

multiply
neq
subtract