[−][src]Struct arrow::builder::BufferBuilder
Buffer builder with zero-copy build method
Methods
impl BufferBuilder<u8>[src]
impl BufferBuilder<u8>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a builder with a fixed initial capacity
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the number of array elements (slots) in the builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the current capacity of the builder (number of elements)
pub fn push(&mut self, v: u8) -> Result<()>[src]
pub fn push(&mut self, v: u8) -> Result<()>Pushes a value into the builder, growing the internal buffer as needed.
pub fn push_slice(&mut self, slice: &[u8]) -> Result<()>[src]
pub fn push_slice(&mut self, slice: &[u8]) -> Result<()>Pushes a slice of type T, growing the internal buffer as needed.
pub fn reserve(&mut self, n: i64) -> Result<()>[src]
pub fn reserve(&mut self, n: i64) -> Result<()>Reserves memory for n elements of type T.
pub fn finish(self) -> Buffer[src]
pub fn finish(self) -> BufferConsumes this builder and returns an immutable Buffer.
impl BufferBuilder<u16>[src]
impl BufferBuilder<u16>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a builder with a fixed initial capacity
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the number of array elements (slots) in the builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the current capacity of the builder (number of elements)
pub fn push(&mut self, v: u16) -> Result<()>[src]
pub fn push(&mut self, v: u16) -> Result<()>Pushes a value into the builder, growing the internal buffer as needed.
pub fn push_slice(&mut self, slice: &[u16]) -> Result<()>[src]
pub fn push_slice(&mut self, slice: &[u16]) -> Result<()>Pushes a slice of type T, growing the internal buffer as needed.
pub fn reserve(&mut self, n: i64) -> Result<()>[src]
pub fn reserve(&mut self, n: i64) -> Result<()>Reserves memory for n elements of type T.
pub fn finish(self) -> Buffer[src]
pub fn finish(self) -> BufferConsumes this builder and returns an immutable Buffer.
impl BufferBuilder<u32>[src]
impl BufferBuilder<u32>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a builder with a fixed initial capacity
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the number of array elements (slots) in the builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the current capacity of the builder (number of elements)
pub fn push(&mut self, v: u32) -> Result<()>[src]
pub fn push(&mut self, v: u32) -> Result<()>Pushes a value into the builder, growing the internal buffer as needed.
pub fn push_slice(&mut self, slice: &[u32]) -> Result<()>[src]
pub fn push_slice(&mut self, slice: &[u32]) -> Result<()>Pushes a slice of type T, growing the internal buffer as needed.
pub fn reserve(&mut self, n: i64) -> Result<()>[src]
pub fn reserve(&mut self, n: i64) -> Result<()>Reserves memory for n elements of type T.
pub fn finish(self) -> Buffer[src]
pub fn finish(self) -> BufferConsumes this builder and returns an immutable Buffer.
impl BufferBuilder<u64>[src]
impl BufferBuilder<u64>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a builder with a fixed initial capacity
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the number of array elements (slots) in the builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the current capacity of the builder (number of elements)
pub fn push(&mut self, v: u64) -> Result<()>[src]
pub fn push(&mut self, v: u64) -> Result<()>Pushes a value into the builder, growing the internal buffer as needed.
pub fn push_slice(&mut self, slice: &[u64]) -> Result<()>[src]
pub fn push_slice(&mut self, slice: &[u64]) -> Result<()>Pushes a slice of type T, growing the internal buffer as needed.
pub fn reserve(&mut self, n: i64) -> Result<()>[src]
pub fn reserve(&mut self, n: i64) -> Result<()>Reserves memory for n elements of type T.
pub fn finish(self) -> Buffer[src]
pub fn finish(self) -> BufferConsumes this builder and returns an immutable Buffer.
impl BufferBuilder<i8>[src]
impl BufferBuilder<i8>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a builder with a fixed initial capacity
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the number of array elements (slots) in the builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the current capacity of the builder (number of elements)
pub fn push(&mut self, v: i8) -> Result<()>[src]
pub fn push(&mut self, v: i8) -> Result<()>Pushes a value into the builder, growing the internal buffer as needed.
pub fn push_slice(&mut self, slice: &[i8]) -> Result<()>[src]
pub fn push_slice(&mut self, slice: &[i8]) -> Result<()>Pushes a slice of type T, growing the internal buffer as needed.
pub fn reserve(&mut self, n: i64) -> Result<()>[src]
pub fn reserve(&mut self, n: i64) -> Result<()>Reserves memory for n elements of type T.
pub fn finish(self) -> Buffer[src]
pub fn finish(self) -> BufferConsumes this builder and returns an immutable Buffer.
impl BufferBuilder<i16>[src]
impl BufferBuilder<i16>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a builder with a fixed initial capacity
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the number of array elements (slots) in the builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the current capacity of the builder (number of elements)
pub fn push(&mut self, v: i16) -> Result<()>[src]
pub fn push(&mut self, v: i16) -> Result<()>Pushes a value into the builder, growing the internal buffer as needed.
pub fn push_slice(&mut self, slice: &[i16]) -> Result<()>[src]
pub fn push_slice(&mut self, slice: &[i16]) -> Result<()>Pushes a slice of type T, growing the internal buffer as needed.
pub fn reserve(&mut self, n: i64) -> Result<()>[src]
pub fn reserve(&mut self, n: i64) -> Result<()>Reserves memory for n elements of type T.
pub fn finish(self) -> Buffer[src]
pub fn finish(self) -> BufferConsumes this builder and returns an immutable Buffer.
impl BufferBuilder<i32>[src]
impl BufferBuilder<i32>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a builder with a fixed initial capacity
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the number of array elements (slots) in the builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the current capacity of the builder (number of elements)
pub fn push(&mut self, v: i32) -> Result<()>[src]
pub fn push(&mut self, v: i32) -> Result<()>Pushes a value into the builder, growing the internal buffer as needed.
pub fn push_slice(&mut self, slice: &[i32]) -> Result<()>[src]
pub fn push_slice(&mut self, slice: &[i32]) -> Result<()>Pushes a slice of type T, growing the internal buffer as needed.
pub fn reserve(&mut self, n: i64) -> Result<()>[src]
pub fn reserve(&mut self, n: i64) -> Result<()>Reserves memory for n elements of type T.
pub fn finish(self) -> Buffer[src]
pub fn finish(self) -> BufferConsumes this builder and returns an immutable Buffer.
impl BufferBuilder<i64>[src]
impl BufferBuilder<i64>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a builder with a fixed initial capacity
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the number of array elements (slots) in the builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the current capacity of the builder (number of elements)
pub fn push(&mut self, v: i64) -> Result<()>[src]
pub fn push(&mut self, v: i64) -> Result<()>Pushes a value into the builder, growing the internal buffer as needed.
pub fn push_slice(&mut self, slice: &[i64]) -> Result<()>[src]
pub fn push_slice(&mut self, slice: &[i64]) -> Result<()>Pushes a slice of type T, growing the internal buffer as needed.
pub fn reserve(&mut self, n: i64) -> Result<()>[src]
pub fn reserve(&mut self, n: i64) -> Result<()>Reserves memory for n elements of type T.
pub fn finish(self) -> Buffer[src]
pub fn finish(self) -> BufferConsumes this builder and returns an immutable Buffer.
impl BufferBuilder<f32>[src]
impl BufferBuilder<f32>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a builder with a fixed initial capacity
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the number of array elements (slots) in the builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the current capacity of the builder (number of elements)
pub fn push(&mut self, v: f32) -> Result<()>[src]
pub fn push(&mut self, v: f32) -> Result<()>Pushes a value into the builder, growing the internal buffer as needed.
pub fn push_slice(&mut self, slice: &[f32]) -> Result<()>[src]
pub fn push_slice(&mut self, slice: &[f32]) -> Result<()>Pushes a slice of type T, growing the internal buffer as needed.
pub fn reserve(&mut self, n: i64) -> Result<()>[src]
pub fn reserve(&mut self, n: i64) -> Result<()>Reserves memory for n elements of type T.
pub fn finish(self) -> Buffer[src]
pub fn finish(self) -> BufferConsumes this builder and returns an immutable Buffer.
impl BufferBuilder<f64>[src]
impl BufferBuilder<f64>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a builder with a fixed initial capacity
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the number of array elements (slots) in the builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the current capacity of the builder (number of elements)
pub fn push(&mut self, v: f64) -> Result<()>[src]
pub fn push(&mut self, v: f64) -> Result<()>Pushes a value into the builder, growing the internal buffer as needed.
pub fn push_slice(&mut self, slice: &[f64]) -> Result<()>[src]
pub fn push_slice(&mut self, slice: &[f64]) -> Result<()>Pushes a slice of type T, growing the internal buffer as needed.
pub fn reserve(&mut self, n: i64) -> Result<()>[src]
pub fn reserve(&mut self, n: i64) -> Result<()>Reserves memory for n elements of type T.
pub fn finish(self) -> Buffer[src]
pub fn finish(self) -> BufferConsumes this builder and returns an immutable Buffer.
impl BufferBuilder<bool>[src]
impl BufferBuilder<bool>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a builder with a fixed initial capacity.
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the number of array elements (slots) in the builder.
pub fn advance(&mut self, i: i64) -> Result<()>[src]
pub fn advance(&mut self, i: i64) -> Result<()>pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the current capacity of the builder (number of elements)
pub fn push(&mut self, v: bool) -> Result<()>[src]
pub fn push(&mut self, v: bool) -> Result<()>Pushes a value into the builder, growing the internal buffer as needed.
pub fn push_slice(&mut self, slice: &[bool]) -> Result<()>[src]
pub fn push_slice(&mut self, slice: &[bool]) -> Result<()>Pushes a slice of type T, growing the internal buffer as needed.
pub fn reserve(&mut self, n: i64) -> Result<()>[src]
pub fn reserve(&mut self, n: i64) -> Result<()>Reserves memory for n elements of type T.
pub fn finish(self) -> Buffer[src]
pub fn finish(self) -> BufferConsumes this and returns an immutable Buffer.