[−][src]Struct arrow::builder::ListArrayBuilder
Array builder for ListArray
Methods
impl<T: ArrayBuilder> ListArrayBuilder<T>[src]
impl<T: ArrayBuilder> ListArrayBuilder<T>pub fn new(values_builder: T) -> Self[src]
pub fn new(values_builder: T) -> SelfCreates a new ListArrayBuilder from a given values array builder
impl ListArrayBuilder<PrimitiveArrayBuilder<bool>>[src]
impl ListArrayBuilder<PrimitiveArrayBuilder<bool>>pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<bool>[src]
pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<bool>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<PrimitiveArrayBuilder<u8>>[src]
impl ListArrayBuilder<PrimitiveArrayBuilder<u8>>pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<u8>[src]
pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<u8>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<PrimitiveArrayBuilder<u16>>[src]
impl ListArrayBuilder<PrimitiveArrayBuilder<u16>>pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<u16>[src]
pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<u16>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<PrimitiveArrayBuilder<u32>>[src]
impl ListArrayBuilder<PrimitiveArrayBuilder<u32>>pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<u32>[src]
pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<u32>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<PrimitiveArrayBuilder<u64>>[src]
impl ListArrayBuilder<PrimitiveArrayBuilder<u64>>pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<u64>[src]
pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<u64>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<PrimitiveArrayBuilder<i8>>[src]
impl ListArrayBuilder<PrimitiveArrayBuilder<i8>>pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<i8>[src]
pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<i8>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<PrimitiveArrayBuilder<i16>>[src]
impl ListArrayBuilder<PrimitiveArrayBuilder<i16>>pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<i16>[src]
pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<i16>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<PrimitiveArrayBuilder<i32>>[src]
impl ListArrayBuilder<PrimitiveArrayBuilder<i32>>pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<i32>[src]
pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<i32>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<PrimitiveArrayBuilder<i64>>[src]
impl ListArrayBuilder<PrimitiveArrayBuilder<i64>>pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<i64>[src]
pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<i64>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<PrimitiveArrayBuilder<f32>>[src]
impl ListArrayBuilder<PrimitiveArrayBuilder<f32>>pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<f32>[src]
pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<f32>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<PrimitiveArrayBuilder<f64>>[src]
impl ListArrayBuilder<PrimitiveArrayBuilder<f64>>pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<f64>[src]
pub fn values(&mut self) -> &mut PrimitiveArrayBuilder<f64>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<bool>>>[src]
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<bool>>>pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<bool>>[src]
pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<bool>>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u8>>>[src]
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u8>>>pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<u8>>[src]
pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<u8>>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u16>>>[src]
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u16>>>pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<u16>>[src]
pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<u16>>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u32>>>[src]
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u32>>>pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<u32>>[src]
pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<u32>>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u64>>>[src]
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u64>>>pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<u64>>[src]
pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<u64>>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i8>>>[src]
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i8>>>pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<i8>>[src]
pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<i8>>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i16>>>[src]
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i16>>>pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<i16>>[src]
pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<i16>>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i32>>>[src]
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i32>>>pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<i32>>[src]
pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<i32>>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i64>>>[src]
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i64>>>pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<i64>>[src]
pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<i64>>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<f32>>>[src]
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<f32>>>pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<f32>>[src]
pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<f32>>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<f64>>>[src]
impl ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<f64>>>pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<f64>>[src]
pub fn values(&mut self) -> &mut ListArrayBuilder<PrimitiveArrayBuilder<f64>>Returns the child array builder as a mutable reference.
This mutable reference can be used to push values into the child array builder,
but you must call append to delimit each distinct list value.
pub fn append(&mut self, is_valid: bool) -> Result<()>[src]
pub fn append(&mut self, is_valid: bool) -> Result<()>Finish the current variable-length list array slot