[][src]Struct arrow::builder::PrimitiveArrayBuilder

pub struct PrimitiveArrayBuilder<T> where
    T: ArrowPrimitiveType
{ /* fields omitted */ }

Array builder for fixed-width primitive types

Methods

impl PrimitiveArrayBuilder<bool>
[src]

Creates a new primitive array builder

Returns the capacity of this builder measured in slots of type T

Pushes a value of type T into the builder

Pushes a null slot into the builder

Pushes an Option<T> into the builder

Pushes a slice of type T into the builder

impl PrimitiveArrayBuilder<u8>
[src]

Creates a new primitive array builder

Returns the capacity of this builder measured in slots of type T

Pushes a value of type T into the builder

Pushes a null slot into the builder

Pushes an Option<T> into the builder

Pushes a slice of type T into the builder

impl PrimitiveArrayBuilder<u16>
[src]

Creates a new primitive array builder

Returns the capacity of this builder measured in slots of type T

Pushes a value of type T into the builder

Pushes a null slot into the builder

Pushes an Option<T> into the builder

Pushes a slice of type T into the builder

impl PrimitiveArrayBuilder<u32>
[src]

Creates a new primitive array builder

Returns the capacity of this builder measured in slots of type T

Pushes a value of type T into the builder

Pushes a null slot into the builder

Pushes an Option<T> into the builder

Pushes a slice of type T into the builder

impl PrimitiveArrayBuilder<u64>
[src]

Creates a new primitive array builder

Returns the capacity of this builder measured in slots of type T

Pushes a value of type T into the builder

Pushes a null slot into the builder

Pushes an Option<T> into the builder

Pushes a slice of type T into the builder

impl PrimitiveArrayBuilder<i8>
[src]

Creates a new primitive array builder

Returns the capacity of this builder measured in slots of type T

Pushes a value of type T into the builder

Pushes a null slot into the builder

Pushes an Option<T> into the builder

Pushes a slice of type T into the builder

impl PrimitiveArrayBuilder<i16>
[src]

Creates a new primitive array builder

Returns the capacity of this builder measured in slots of type T

Pushes a value of type T into the builder

Pushes a null slot into the builder

Pushes an Option<T> into the builder

Pushes a slice of type T into the builder

impl PrimitiveArrayBuilder<i32>
[src]

Creates a new primitive array builder

Returns the capacity of this builder measured in slots of type T

Pushes a value of type T into the builder

Pushes a null slot into the builder

Pushes an Option<T> into the builder

Pushes a slice of type T into the builder

impl PrimitiveArrayBuilder<i64>
[src]

Creates a new primitive array builder

Returns the capacity of this builder measured in slots of type T

Pushes a value of type T into the builder

Pushes a null slot into the builder

Pushes an Option<T> into the builder

Pushes a slice of type T into the builder

impl PrimitiveArrayBuilder<f32>
[src]

Creates a new primitive array builder

Returns the capacity of this builder measured in slots of type T

Pushes a value of type T into the builder

Pushes a null slot into the builder

Pushes an Option<T> into the builder

Pushes a slice of type T into the builder

impl PrimitiveArrayBuilder<f64>
[src]

Creates a new primitive array builder

Returns the capacity of this builder measured in slots of type T

Pushes a value of type T into the builder

Pushes a null slot into the builder

Pushes an Option<T> into the builder

Pushes a slice of type T into the builder