[−][src]Trait arrow::builder::ArrayBuilder
Trait for dealing with different array builders at runtime
Associated Types
type ArrayType
The type of array that this builder creates
Required Methods
fn into_any(self) -> Box<dyn Any>
Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64
Returns the number of array slots in the builder
fn finish(self) -> Self::ArrayType
Builds the array
Implementors
impl ArrayBuilder for BinaryArrayBuilder[src]
impl ArrayBuilder for BinaryArrayBuildertype ArrayType = BinaryArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> BinaryArray[src]
fn finish(self) -> BinaryArrayBuilds the BinaryArray
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<bool>>>[src]
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<bool>>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<f32>>>[src]
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<f32>>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<f64>>>[src]
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<f64>>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i16>>>[src]
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i16>>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i32>>>[src]
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i32>>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i64>>>[src]
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i64>>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i8>>>[src]
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<i8>>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u16>>>[src]
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u16>>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u32>>>[src]
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u32>>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u64>>>[src]
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u64>>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u8>>>[src]
impl ArrayBuilder for ListArrayBuilder<ListArrayBuilder<PrimitiveArrayBuilder<u8>>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<bool>>[src]
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<bool>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<f32>>[src]
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<f32>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<f64>>[src]
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<f64>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<i16>>[src]
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<i16>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<i32>>[src]
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<i32>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<i64>>[src]
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<i64>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<i8>>[src]
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<i8>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<u16>>[src]
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<u16>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<u32>>[src]
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<u32>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<u64>>[src]
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<u64>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<u8>>[src]
impl ArrayBuilder for ListArrayBuilder<PrimitiveArrayBuilder<u8>>type ArrayType = ListArray
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method.
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> ListArray[src]
fn finish(self) -> ListArrayBuilds the ListArray
impl ArrayBuilder for PrimitiveArrayBuilder<bool>[src]
impl ArrayBuilder for PrimitiveArrayBuilder<bool>type ArrayType = PrimitiveArray<bool>
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> PrimitiveArray<bool>[src]
fn finish(self) -> PrimitiveArray<bool>Builds the PrimitiveArray
impl ArrayBuilder for PrimitiveArrayBuilder<f32>[src]
impl ArrayBuilder for PrimitiveArrayBuilder<f32>type ArrayType = PrimitiveArray<f32>
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> PrimitiveArray<f32>[src]
fn finish(self) -> PrimitiveArray<f32>Builds the PrimitiveArray
impl ArrayBuilder for PrimitiveArrayBuilder<f64>[src]
impl ArrayBuilder for PrimitiveArrayBuilder<f64>type ArrayType = PrimitiveArray<f64>
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> PrimitiveArray<f64>[src]
fn finish(self) -> PrimitiveArray<f64>Builds the PrimitiveArray
impl ArrayBuilder for PrimitiveArrayBuilder<i16>[src]
impl ArrayBuilder for PrimitiveArrayBuilder<i16>type ArrayType = PrimitiveArray<i16>
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> PrimitiveArray<i16>[src]
fn finish(self) -> PrimitiveArray<i16>Builds the PrimitiveArray
impl ArrayBuilder for PrimitiveArrayBuilder<i32>[src]
impl ArrayBuilder for PrimitiveArrayBuilder<i32>type ArrayType = PrimitiveArray<i32>
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> PrimitiveArray<i32>[src]
fn finish(self) -> PrimitiveArray<i32>Builds the PrimitiveArray
impl ArrayBuilder for PrimitiveArrayBuilder<i64>[src]
impl ArrayBuilder for PrimitiveArrayBuilder<i64>type ArrayType = PrimitiveArray<i64>
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> PrimitiveArray<i64>[src]
fn finish(self) -> PrimitiveArray<i64>Builds the PrimitiveArray
impl ArrayBuilder for PrimitiveArrayBuilder<i8>[src]
impl ArrayBuilder for PrimitiveArrayBuilder<i8>type ArrayType = PrimitiveArray<i8>
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> PrimitiveArray<i8>[src]
fn finish(self) -> PrimitiveArray<i8>Builds the PrimitiveArray
impl ArrayBuilder for PrimitiveArrayBuilder<u16>[src]
impl ArrayBuilder for PrimitiveArrayBuilder<u16>type ArrayType = PrimitiveArray<u16>
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> PrimitiveArray<u16>[src]
fn finish(self) -> PrimitiveArray<u16>Builds the PrimitiveArray
impl ArrayBuilder for PrimitiveArrayBuilder<u32>[src]
impl ArrayBuilder for PrimitiveArrayBuilder<u32>type ArrayType = PrimitiveArray<u32>
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> PrimitiveArray<u32>[src]
fn finish(self) -> PrimitiveArray<u32>Builds the PrimitiveArray
impl ArrayBuilder for PrimitiveArrayBuilder<u64>[src]
impl ArrayBuilder for PrimitiveArrayBuilder<u64>type ArrayType = PrimitiveArray<u64>
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> PrimitiveArray<u64>[src]
fn finish(self) -> PrimitiveArray<u64>Builds the PrimitiveArray
impl ArrayBuilder for PrimitiveArrayBuilder<u8>[src]
impl ArrayBuilder for PrimitiveArrayBuilder<u8>type ArrayType = PrimitiveArray<u8>
fn into_any(self) -> Box<dyn Any>[src]
fn into_any(self) -> Box<dyn Any>Returns the builder as an owned Any type so that it can be downcast to a specific
implementation before calling it's finish method
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the number of array slots in the builder
fn finish(self) -> PrimitiveArray<u8>[src]
fn finish(self) -> PrimitiveArray<u8>Builds the PrimitiveArray