take_arrays_unchecked

Function take_arrays_unchecked 

pub unsafe fn take_arrays_unchecked(
    arrays: &[Arc<dyn Array>],
    indices: &dyn Array,
) -> Result<Vec<Arc<dyn Array>>, ArrowError>
For each ArrayRef in the Vec<ArrayRef>, take elements by index and create a new Vec<ArrayRef> from those indices, without bounds checking.

Safety

Caller must ensure all values in indices are valid indices into each array (i.e. < array.len()). Out-of-bounds indices will cause undefined behavior.

Errors

Returns an error if an index value cannot be cast to usize.