product

Function product 

pub fn product<T>(
    array: &PrimitiveArray<T>,
) -> Option<<T as ArrowPrimitiveType>::Native>
Returns the product of values in the primitive array.

Returns None if the array is empty or only contains null values.

This doesn’t detect overflow in release mode by default. Once overflowing, the result will wrap around. For an overflow-checking variant, use product_checked instead.