eq_ignore_ascii_case

Function eq_ignore_ascii_case 

pub fn eq_ignore_ascii_case(
    left: &dyn Datum,
    right: &dyn Datum,
) -> Result<BooleanArray, ArrowError>
Perform equality check on two arrays using an ASCII case-insensitive match.

left and right must be the same type, and one of

  • Utf8
  • LargeUtf8
  • Utf8View

Example

let strings = StringArray::from(vec!["arrow", "rs", "arrow-rS", "Parquet"]);
let patterns = StringArray::from(vec!["ARROW", "rS", "ARROW-rs", "arrow"]);

let result = eq_ignore_ascii_case(&strings, &patterns).unwrap();
assert_eq!(result, BooleanArray::from(vec![true, true, true, false]));