concat_elements_binary_view_array

Function concat_elements_binary_view_array 

pub fn concat_elements_binary_view_array(
    left: &GenericByteViewArray<BinaryViewType>,
    right: &GenericByteViewArray<BinaryViewType>,
) -> Result<GenericByteViewArray<BinaryViewType>, ArrowError>
Concatenates two BinaryViewArrays element-wise. If either element is Null, the result element is also Null.

Errors

  • Returns an error if the input arrays have different lengths.
  • Returns an error if any concatenated value exceeds u32::MAX in length.