[−][src]Struct arrow::tensor::Tensor
Tensor of primitive types
Methods
impl<'a, T: ArrowPrimitiveType> Tensor<'a, T>[src]
impl<'a, T: ArrowPrimitiveType> Tensor<'a, T>pub fn new(
buffer: Buffer,
shape: Option<Vec<usize>>,
strides: Option<Vec<usize>>,
names: Option<Vec<&'a str>>
) -> Self[src]
pub fn new(
buffer: Buffer,
shape: Option<Vec<usize>>,
strides: Option<Vec<usize>>,
names: Option<Vec<&'a str>>
) -> SelfCreates a new Tensor
pub fn new_row_major(
buffer: Buffer,
shape: Option<Vec<usize>>,
names: Option<Vec<&'a str>>
) -> Self[src]
pub fn new_row_major(
buffer: Buffer,
shape: Option<Vec<usize>>,
names: Option<Vec<&'a str>>
) -> SelfCreates a new Tensor using row major memory layout
pub fn new_column_major(
buffer: Buffer,
shape: Option<Vec<usize>>,
names: Option<Vec<&'a str>>
) -> Self[src]
pub fn new_column_major(
buffer: Buffer,
shape: Option<Vec<usize>>,
names: Option<Vec<&'a str>>
) -> SelfCreates a new Tensor using column major memory layout
pub fn data_type(&self) -> &DataType[src]
pub fn data_type(&self) -> &DataTypeThe data type of the Tensor
pub fn shape(&self) -> Option<&Vec<usize>>[src]
pub fn shape(&self) -> Option<&Vec<usize>>The sizes of the dimensions
pub fn data(&self) -> &Buffer[src]
pub fn data(&self) -> &BufferReturns a reference to the underlying Buffer
pub fn strides(&self) -> Option<&Vec<usize>>[src]
pub fn strides(&self) -> Option<&Vec<usize>>The number of bytes between elements in each dimension
pub fn names(&self) -> Option<&Vec<&'a str>>[src]
pub fn names(&self) -> Option<&Vec<&'a str>>The names of the dimensions
pub fn ndim(&self) -> usize[src]
pub fn ndim(&self) -> usizeThe number of dimensions
pub fn dim_name(&self, i: usize) -> Option<&'a str>[src]
pub fn dim_name(&self, i: usize) -> Option<&'a str>The name of dimension i
pub fn size(&self) -> usize[src]
pub fn size(&self) -> usizeThe total number of elements in the Tensor
pub fn is_contiguous(&self) -> bool[src]
pub fn is_contiguous(&self) -> boolIndicates if the data is laid out contiguously in memory
pub fn is_row_major(&self) -> bool[src]
pub fn is_row_major(&self) -> boolIndicates if the memory layout row major
pub fn is_column_major(&self) -> bool[src]
pub fn is_column_major(&self) -> boolIndicates if the memory layout column major