create_binary_array_with_len_range_and_prefix_and_seed

Function create_binary_array_with_len_range_and_prefix_and_seed 

pub fn create_binary_array_with_len_range_and_prefix_and_seed<Offset: OffsetSizeTrait>(
    size: usize,
    null_density: f32,
    min_len: usize,
    max_len: usize,
    prefix: &[u8],
    seed: u64,
) -> GenericBinaryArray<Offset>
Creates a random GenericBinaryArray of a given size and null_density filling it with random bytes with lengths in the specified range, all starting with the provided prefix, generated using the provided seed.

Panics

Panics if min_len > max_len or prefix.len() > max_len