[−][src]Struct arrow::array::PrimitiveArray
Array whose elements are of primitive types.
Methods
impl PrimitiveArray<u8>[src]
impl PrimitiveArray<u8>pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Self[src]
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Selfpub fn values(&self) -> Buffer[src]
pub fn values(&self) -> BufferReturns a Buffer holds all the values of this array.
Note this doesn't take account into the offset of this array.
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the length of this array
pub fn raw_values(&self) -> *const u8[src]
pub fn raw_values(&self) -> *const u8Returns a raw pointer to the values of this array.
pub fn value(&self, i: i64) -> u8[src]
pub fn value(&self, i: i64) -> u8Returns the primitive value at index i.
Note this doesn't do any bound checking, for performance reason.
pub fn value_slice(&self, offset: i64, len: i64) -> &[u8][src]
pub fn value_slice(&self, offset: i64, len: i64) -> &[u8]Returns a slice for the given offset and length
Note this doesn't do any bound checking, for performance reason.
pub fn min(&self) -> Option<u8>[src]
pub fn min(&self) -> Option<u8>Returns the minimum value in the array, according to the natural order.
pub fn max(&self) -> Option<u8>[src]
pub fn max(&self) -> Option<u8>Returns the maximum value in the array, according to the natural order.
pub fn add(&self, other: &PrimitiveArray<u8>) -> PrimitiveArray<u8>[src]
pub fn add(&self, other: &PrimitiveArray<u8>) -> PrimitiveArray<u8>pub fn subtract(&self, other: &PrimitiveArray<u8>) -> PrimitiveArray<u8>[src]
pub fn subtract(&self, other: &PrimitiveArray<u8>) -> PrimitiveArray<u8>pub fn multiply(&self, other: &PrimitiveArray<u8>) -> PrimitiveArray<u8>[src]
pub fn multiply(&self, other: &PrimitiveArray<u8>) -> PrimitiveArray<u8>pub fn divide(&self, other: &PrimitiveArray<u8>) -> PrimitiveArray<u8>[src]
pub fn divide(&self, other: &PrimitiveArray<u8>) -> PrimitiveArray<u8>pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<u8>[src]
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<u8>impl PrimitiveArray<u16>[src]
impl PrimitiveArray<u16>pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Self[src]
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Selfpub fn values(&self) -> Buffer[src]
pub fn values(&self) -> BufferReturns a Buffer holds all the values of this array.
Note this doesn't take account into the offset of this array.
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the length of this array
pub fn raw_values(&self) -> *const u16[src]
pub fn raw_values(&self) -> *const u16Returns a raw pointer to the values of this array.
pub fn value(&self, i: i64) -> u16[src]
pub fn value(&self, i: i64) -> u16Returns the primitive value at index i.
Note this doesn't do any bound checking, for performance reason.
pub fn value_slice(&self, offset: i64, len: i64) -> &[u16][src]
pub fn value_slice(&self, offset: i64, len: i64) -> &[u16]Returns a slice for the given offset and length
Note this doesn't do any bound checking, for performance reason.
pub fn min(&self) -> Option<u16>[src]
pub fn min(&self) -> Option<u16>Returns the minimum value in the array, according to the natural order.
pub fn max(&self) -> Option<u16>[src]
pub fn max(&self) -> Option<u16>Returns the maximum value in the array, according to the natural order.
pub fn add(&self, other: &PrimitiveArray<u16>) -> PrimitiveArray<u16>[src]
pub fn add(&self, other: &PrimitiveArray<u16>) -> PrimitiveArray<u16>pub fn subtract(&self, other: &PrimitiveArray<u16>) -> PrimitiveArray<u16>[src]
pub fn subtract(&self, other: &PrimitiveArray<u16>) -> PrimitiveArray<u16>pub fn multiply(&self, other: &PrimitiveArray<u16>) -> PrimitiveArray<u16>[src]
pub fn multiply(&self, other: &PrimitiveArray<u16>) -> PrimitiveArray<u16>pub fn divide(&self, other: &PrimitiveArray<u16>) -> PrimitiveArray<u16>[src]
pub fn divide(&self, other: &PrimitiveArray<u16>) -> PrimitiveArray<u16>pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<u16>[src]
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<u16>impl PrimitiveArray<u32>[src]
impl PrimitiveArray<u32>pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Self[src]
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Selfpub fn values(&self) -> Buffer[src]
pub fn values(&self) -> BufferReturns a Buffer holds all the values of this array.
Note this doesn't take account into the offset of this array.
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the length of this array
pub fn raw_values(&self) -> *const u32[src]
pub fn raw_values(&self) -> *const u32Returns a raw pointer to the values of this array.
pub fn value(&self, i: i64) -> u32[src]
pub fn value(&self, i: i64) -> u32Returns the primitive value at index i.
Note this doesn't do any bound checking, for performance reason.
pub fn value_slice(&self, offset: i64, len: i64) -> &[u32][src]
pub fn value_slice(&self, offset: i64, len: i64) -> &[u32]Returns a slice for the given offset and length
Note this doesn't do any bound checking, for performance reason.
pub fn min(&self) -> Option<u32>[src]
pub fn min(&self) -> Option<u32>Returns the minimum value in the array, according to the natural order.
pub fn max(&self) -> Option<u32>[src]
pub fn max(&self) -> Option<u32>Returns the maximum value in the array, according to the natural order.
pub fn add(&self, other: &PrimitiveArray<u32>) -> PrimitiveArray<u32>[src]
pub fn add(&self, other: &PrimitiveArray<u32>) -> PrimitiveArray<u32>pub fn subtract(&self, other: &PrimitiveArray<u32>) -> PrimitiveArray<u32>[src]
pub fn subtract(&self, other: &PrimitiveArray<u32>) -> PrimitiveArray<u32>pub fn multiply(&self, other: &PrimitiveArray<u32>) -> PrimitiveArray<u32>[src]
pub fn multiply(&self, other: &PrimitiveArray<u32>) -> PrimitiveArray<u32>pub fn divide(&self, other: &PrimitiveArray<u32>) -> PrimitiveArray<u32>[src]
pub fn divide(&self, other: &PrimitiveArray<u32>) -> PrimitiveArray<u32>pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<u32>[src]
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<u32>impl PrimitiveArray<u64>[src]
impl PrimitiveArray<u64>pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Self[src]
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Selfpub fn values(&self) -> Buffer[src]
pub fn values(&self) -> BufferReturns a Buffer holds all the values of this array.
Note this doesn't take account into the offset of this array.
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the length of this array
pub fn raw_values(&self) -> *const u64[src]
pub fn raw_values(&self) -> *const u64Returns a raw pointer to the values of this array.
pub fn value(&self, i: i64) -> u64[src]
pub fn value(&self, i: i64) -> u64Returns the primitive value at index i.
Note this doesn't do any bound checking, for performance reason.
pub fn value_slice(&self, offset: i64, len: i64) -> &[u64][src]
pub fn value_slice(&self, offset: i64, len: i64) -> &[u64]Returns a slice for the given offset and length
Note this doesn't do any bound checking, for performance reason.
pub fn min(&self) -> Option<u64>[src]
pub fn min(&self) -> Option<u64>Returns the minimum value in the array, according to the natural order.
pub fn max(&self) -> Option<u64>[src]
pub fn max(&self) -> Option<u64>Returns the maximum value in the array, according to the natural order.
pub fn add(&self, other: &PrimitiveArray<u64>) -> PrimitiveArray<u64>[src]
pub fn add(&self, other: &PrimitiveArray<u64>) -> PrimitiveArray<u64>pub fn subtract(&self, other: &PrimitiveArray<u64>) -> PrimitiveArray<u64>[src]
pub fn subtract(&self, other: &PrimitiveArray<u64>) -> PrimitiveArray<u64>pub fn multiply(&self, other: &PrimitiveArray<u64>) -> PrimitiveArray<u64>[src]
pub fn multiply(&self, other: &PrimitiveArray<u64>) -> PrimitiveArray<u64>pub fn divide(&self, other: &PrimitiveArray<u64>) -> PrimitiveArray<u64>[src]
pub fn divide(&self, other: &PrimitiveArray<u64>) -> PrimitiveArray<u64>pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<u64>[src]
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<u64>impl PrimitiveArray<i8>[src]
impl PrimitiveArray<i8>pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Self[src]
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Selfpub fn values(&self) -> Buffer[src]
pub fn values(&self) -> BufferReturns a Buffer holds all the values of this array.
Note this doesn't take account into the offset of this array.
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the length of this array
pub fn raw_values(&self) -> *const i8[src]
pub fn raw_values(&self) -> *const i8Returns a raw pointer to the values of this array.
pub fn value(&self, i: i64) -> i8[src]
pub fn value(&self, i: i64) -> i8Returns the primitive value at index i.
Note this doesn't do any bound checking, for performance reason.
pub fn value_slice(&self, offset: i64, len: i64) -> &[i8][src]
pub fn value_slice(&self, offset: i64, len: i64) -> &[i8]Returns a slice for the given offset and length
Note this doesn't do any bound checking, for performance reason.
pub fn min(&self) -> Option<i8>[src]
pub fn min(&self) -> Option<i8>Returns the minimum value in the array, according to the natural order.
pub fn max(&self) -> Option<i8>[src]
pub fn max(&self) -> Option<i8>Returns the maximum value in the array, according to the natural order.
pub fn add(&self, other: &PrimitiveArray<i8>) -> PrimitiveArray<i8>[src]
pub fn add(&self, other: &PrimitiveArray<i8>) -> PrimitiveArray<i8>pub fn subtract(&self, other: &PrimitiveArray<i8>) -> PrimitiveArray<i8>[src]
pub fn subtract(&self, other: &PrimitiveArray<i8>) -> PrimitiveArray<i8>pub fn multiply(&self, other: &PrimitiveArray<i8>) -> PrimitiveArray<i8>[src]
pub fn multiply(&self, other: &PrimitiveArray<i8>) -> PrimitiveArray<i8>pub fn divide(&self, other: &PrimitiveArray<i8>) -> PrimitiveArray<i8>[src]
pub fn divide(&self, other: &PrimitiveArray<i8>) -> PrimitiveArray<i8>pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<i8>[src]
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<i8>impl PrimitiveArray<i16>[src]
impl PrimitiveArray<i16>pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Self[src]
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Selfpub fn values(&self) -> Buffer[src]
pub fn values(&self) -> BufferReturns a Buffer holds all the values of this array.
Note this doesn't take account into the offset of this array.
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the length of this array
pub fn raw_values(&self) -> *const i16[src]
pub fn raw_values(&self) -> *const i16Returns a raw pointer to the values of this array.
pub fn value(&self, i: i64) -> i16[src]
pub fn value(&self, i: i64) -> i16Returns the primitive value at index i.
Note this doesn't do any bound checking, for performance reason.
pub fn value_slice(&self, offset: i64, len: i64) -> &[i16][src]
pub fn value_slice(&self, offset: i64, len: i64) -> &[i16]Returns a slice for the given offset and length
Note this doesn't do any bound checking, for performance reason.
pub fn min(&self) -> Option<i16>[src]
pub fn min(&self) -> Option<i16>Returns the minimum value in the array, according to the natural order.
pub fn max(&self) -> Option<i16>[src]
pub fn max(&self) -> Option<i16>Returns the maximum value in the array, according to the natural order.
pub fn add(&self, other: &PrimitiveArray<i16>) -> PrimitiveArray<i16>[src]
pub fn add(&self, other: &PrimitiveArray<i16>) -> PrimitiveArray<i16>pub fn subtract(&self, other: &PrimitiveArray<i16>) -> PrimitiveArray<i16>[src]
pub fn subtract(&self, other: &PrimitiveArray<i16>) -> PrimitiveArray<i16>pub fn multiply(&self, other: &PrimitiveArray<i16>) -> PrimitiveArray<i16>[src]
pub fn multiply(&self, other: &PrimitiveArray<i16>) -> PrimitiveArray<i16>pub fn divide(&self, other: &PrimitiveArray<i16>) -> PrimitiveArray<i16>[src]
pub fn divide(&self, other: &PrimitiveArray<i16>) -> PrimitiveArray<i16>pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<i16>[src]
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<i16>impl PrimitiveArray<i32>[src]
impl PrimitiveArray<i32>pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Self[src]
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Selfpub fn values(&self) -> Buffer[src]
pub fn values(&self) -> BufferReturns a Buffer holds all the values of this array.
Note this doesn't take account into the offset of this array.
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the length of this array
pub fn raw_values(&self) -> *const i32[src]
pub fn raw_values(&self) -> *const i32Returns a raw pointer to the values of this array.
pub fn value(&self, i: i64) -> i32[src]
pub fn value(&self, i: i64) -> i32Returns the primitive value at index i.
Note this doesn't do any bound checking, for performance reason.
pub fn value_slice(&self, offset: i64, len: i64) -> &[i32][src]
pub fn value_slice(&self, offset: i64, len: i64) -> &[i32]Returns a slice for the given offset and length
Note this doesn't do any bound checking, for performance reason.
pub fn min(&self) -> Option<i32>[src]
pub fn min(&self) -> Option<i32>Returns the minimum value in the array, according to the natural order.
pub fn max(&self) -> Option<i32>[src]
pub fn max(&self) -> Option<i32>Returns the maximum value in the array, according to the natural order.
pub fn add(&self, other: &PrimitiveArray<i32>) -> PrimitiveArray<i32>[src]
pub fn add(&self, other: &PrimitiveArray<i32>) -> PrimitiveArray<i32>pub fn subtract(&self, other: &PrimitiveArray<i32>) -> PrimitiveArray<i32>[src]
pub fn subtract(&self, other: &PrimitiveArray<i32>) -> PrimitiveArray<i32>pub fn multiply(&self, other: &PrimitiveArray<i32>) -> PrimitiveArray<i32>[src]
pub fn multiply(&self, other: &PrimitiveArray<i32>) -> PrimitiveArray<i32>pub fn divide(&self, other: &PrimitiveArray<i32>) -> PrimitiveArray<i32>[src]
pub fn divide(&self, other: &PrimitiveArray<i32>) -> PrimitiveArray<i32>pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<i32>[src]
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<i32>impl PrimitiveArray<i64>[src]
impl PrimitiveArray<i64>pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Self[src]
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Selfpub fn values(&self) -> Buffer[src]
pub fn values(&self) -> BufferReturns a Buffer holds all the values of this array.
Note this doesn't take account into the offset of this array.
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the length of this array
pub fn raw_values(&self) -> *const i64[src]
pub fn raw_values(&self) -> *const i64Returns a raw pointer to the values of this array.
pub fn value(&self, i: i64) -> i64[src]
pub fn value(&self, i: i64) -> i64Returns the primitive value at index i.
Note this doesn't do any bound checking, for performance reason.
pub fn value_slice(&self, offset: i64, len: i64) -> &[i64][src]
pub fn value_slice(&self, offset: i64, len: i64) -> &[i64]Returns a slice for the given offset and length
Note this doesn't do any bound checking, for performance reason.
pub fn min(&self) -> Option<i64>[src]
pub fn min(&self) -> Option<i64>Returns the minimum value in the array, according to the natural order.
pub fn max(&self) -> Option<i64>[src]
pub fn max(&self) -> Option<i64>Returns the maximum value in the array, according to the natural order.
pub fn add(&self, other: &PrimitiveArray<i64>) -> PrimitiveArray<i64>[src]
pub fn add(&self, other: &PrimitiveArray<i64>) -> PrimitiveArray<i64>pub fn subtract(&self, other: &PrimitiveArray<i64>) -> PrimitiveArray<i64>[src]
pub fn subtract(&self, other: &PrimitiveArray<i64>) -> PrimitiveArray<i64>pub fn multiply(&self, other: &PrimitiveArray<i64>) -> PrimitiveArray<i64>[src]
pub fn multiply(&self, other: &PrimitiveArray<i64>) -> PrimitiveArray<i64>pub fn divide(&self, other: &PrimitiveArray<i64>) -> PrimitiveArray<i64>[src]
pub fn divide(&self, other: &PrimitiveArray<i64>) -> PrimitiveArray<i64>pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<i64>[src]
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<i64>impl PrimitiveArray<f32>[src]
impl PrimitiveArray<f32>pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Self[src]
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Selfpub fn values(&self) -> Buffer[src]
pub fn values(&self) -> BufferReturns a Buffer holds all the values of this array.
Note this doesn't take account into the offset of this array.
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the length of this array
pub fn raw_values(&self) -> *const f32[src]
pub fn raw_values(&self) -> *const f32Returns a raw pointer to the values of this array.
pub fn value(&self, i: i64) -> f32[src]
pub fn value(&self, i: i64) -> f32Returns the primitive value at index i.
Note this doesn't do any bound checking, for performance reason.
pub fn value_slice(&self, offset: i64, len: i64) -> &[f32][src]
pub fn value_slice(&self, offset: i64, len: i64) -> &[f32]Returns a slice for the given offset and length
Note this doesn't do any bound checking, for performance reason.
pub fn min(&self) -> Option<f32>[src]
pub fn min(&self) -> Option<f32>Returns the minimum value in the array, according to the natural order.
pub fn max(&self) -> Option<f32>[src]
pub fn max(&self) -> Option<f32>Returns the maximum value in the array, according to the natural order.
pub fn add(&self, other: &PrimitiveArray<f32>) -> PrimitiveArray<f32>[src]
pub fn add(&self, other: &PrimitiveArray<f32>) -> PrimitiveArray<f32>pub fn subtract(&self, other: &PrimitiveArray<f32>) -> PrimitiveArray<f32>[src]
pub fn subtract(&self, other: &PrimitiveArray<f32>) -> PrimitiveArray<f32>pub fn multiply(&self, other: &PrimitiveArray<f32>) -> PrimitiveArray<f32>[src]
pub fn multiply(&self, other: &PrimitiveArray<f32>) -> PrimitiveArray<f32>pub fn divide(&self, other: &PrimitiveArray<f32>) -> PrimitiveArray<f32>[src]
pub fn divide(&self, other: &PrimitiveArray<f32>) -> PrimitiveArray<f32>pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<f32>[src]
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<f32>impl PrimitiveArray<f64>[src]
impl PrimitiveArray<f64>pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Self[src]
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Selfpub fn values(&self) -> Buffer[src]
pub fn values(&self) -> BufferReturns a Buffer holds all the values of this array.
Note this doesn't take account into the offset of this array.
pub fn len(&self) -> i64[src]
pub fn len(&self) -> i64Returns the length of this array
pub fn raw_values(&self) -> *const f64[src]
pub fn raw_values(&self) -> *const f64Returns a raw pointer to the values of this array.
pub fn value(&self, i: i64) -> f64[src]
pub fn value(&self, i: i64) -> f64Returns the primitive value at index i.
Note this doesn't do any bound checking, for performance reason.
pub fn value_slice(&self, offset: i64, len: i64) -> &[f64][src]
pub fn value_slice(&self, offset: i64, len: i64) -> &[f64]Returns a slice for the given offset and length
Note this doesn't do any bound checking, for performance reason.
pub fn min(&self) -> Option<f64>[src]
pub fn min(&self) -> Option<f64>Returns the minimum value in the array, according to the natural order.
pub fn max(&self) -> Option<f64>[src]
pub fn max(&self) -> Option<f64>Returns the maximum value in the array, according to the natural order.
pub fn add(&self, other: &PrimitiveArray<f64>) -> PrimitiveArray<f64>[src]
pub fn add(&self, other: &PrimitiveArray<f64>) -> PrimitiveArray<f64>pub fn subtract(&self, other: &PrimitiveArray<f64>) -> PrimitiveArray<f64>[src]
pub fn subtract(&self, other: &PrimitiveArray<f64>) -> PrimitiveArray<f64>pub fn multiply(&self, other: &PrimitiveArray<f64>) -> PrimitiveArray<f64>[src]
pub fn multiply(&self, other: &PrimitiveArray<f64>) -> PrimitiveArray<f64>pub fn divide(&self, other: &PrimitiveArray<f64>) -> PrimitiveArray<f64>[src]
pub fn divide(&self, other: &PrimitiveArray<f64>) -> PrimitiveArray<f64>pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<f64>[src]
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<f64>impl PrimitiveArray<bool>[src]
impl PrimitiveArray<bool>Specific implementation for Boolean arrays due to bit-packing
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Self[src]
pub fn new(length: i64, values: Buffer, null_count: i64, offset: i64) -> Selfpub fn values(&self) -> Buffer[src]
pub fn values(&self) -> BufferReturns a Buffer holds all the values of this array.
Note this doesn't take account into the offset of this array.
pub fn value(&self, i: i64) -> bool[src]
pub fn value(&self, i: i64) -> boolReturns the boolean value at index i.
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<bool>[src]
pub fn builder(capacity: i64) -> PrimitiveArrayBuilder<bool>Trait Implementations
impl<T: ArrowPrimitiveType> Array for PrimitiveArray<T>[src]
impl<T: ArrowPrimitiveType> Array for PrimitiveArray<T>fn as_any(&self) -> &dyn Any[src]
fn as_any(&self) -> &dyn Anyfn data(&self) -> ArrayDataRef[src]
fn data(&self) -> ArrayDataReffn data_ref(&self) -> &ArrayDataRef[src]
fn data_ref(&self) -> &ArrayDataReffn data_type(&self) -> &DataType[src]
fn data_type(&self) -> &DataTypeReturns a reference to the data type of this array
fn len(&self) -> i64[src]
fn len(&self) -> i64Returns the length (i.e., number of elements) of this array
fn offset(&self) -> i64[src]
fn offset(&self) -> i64Returns the offset of this array
fn is_null(&self, i: i64) -> bool[src]
fn is_null(&self, i: i64) -> boolReturns whether the element at index i is null
fn is_valid(&self, i: i64) -> bool[src]
fn is_valid(&self, i: i64) -> boolReturns whether the element at index i is not null
fn null_count(&self) -> i64[src]
fn null_count(&self) -> i64Returns the total number of nulls in this array
impl From<Vec<u8>> for PrimitiveArray<u8>[src]
impl From<Vec<u8>> for PrimitiveArray<u8>Constructs a primitive array from a vector. Should only be used for testing.
impl From<Vec<Option<u8>>> for PrimitiveArray<u8>[src]
impl From<Vec<Option<u8>>> for PrimitiveArray<u8>impl From<Arc<ArrayData>> for PrimitiveArray<u8>[src]
impl From<Arc<ArrayData>> for PrimitiveArray<u8>Constructs a PrimitiveArray from an array data reference.
fn from(data: ArrayDataRef) -> Self[src]
fn from(data: ArrayDataRef) -> Selfimpl From<Vec<u16>> for PrimitiveArray<u16>[src]
impl From<Vec<u16>> for PrimitiveArray<u16>Constructs a primitive array from a vector. Should only be used for testing.
impl From<Vec<Option<u16>>> for PrimitiveArray<u16>[src]
impl From<Vec<Option<u16>>> for PrimitiveArray<u16>impl From<Arc<ArrayData>> for PrimitiveArray<u16>[src]
impl From<Arc<ArrayData>> for PrimitiveArray<u16>Constructs a PrimitiveArray from an array data reference.
fn from(data: ArrayDataRef) -> Self[src]
fn from(data: ArrayDataRef) -> Selfimpl From<Vec<u32>> for PrimitiveArray<u32>[src]
impl From<Vec<u32>> for PrimitiveArray<u32>Constructs a primitive array from a vector. Should only be used for testing.
impl From<Vec<Option<u32>>> for PrimitiveArray<u32>[src]
impl From<Vec<Option<u32>>> for PrimitiveArray<u32>impl From<Arc<ArrayData>> for PrimitiveArray<u32>[src]
impl From<Arc<ArrayData>> for PrimitiveArray<u32>Constructs a PrimitiveArray from an array data reference.
fn from(data: ArrayDataRef) -> Self[src]
fn from(data: ArrayDataRef) -> Selfimpl From<Vec<u64>> for PrimitiveArray<u64>[src]
impl From<Vec<u64>> for PrimitiveArray<u64>Constructs a primitive array from a vector. Should only be used for testing.
impl From<Vec<Option<u64>>> for PrimitiveArray<u64>[src]
impl From<Vec<Option<u64>>> for PrimitiveArray<u64>impl From<Arc<ArrayData>> for PrimitiveArray<u64>[src]
impl From<Arc<ArrayData>> for PrimitiveArray<u64>Constructs a PrimitiveArray from an array data reference.
fn from(data: ArrayDataRef) -> Self[src]
fn from(data: ArrayDataRef) -> Selfimpl From<Vec<i8>> for PrimitiveArray<i8>[src]
impl From<Vec<i8>> for PrimitiveArray<i8>Constructs a primitive array from a vector. Should only be used for testing.
impl From<Vec<Option<i8>>> for PrimitiveArray<i8>[src]
impl From<Vec<Option<i8>>> for PrimitiveArray<i8>impl From<Arc<ArrayData>> for PrimitiveArray<i8>[src]
impl From<Arc<ArrayData>> for PrimitiveArray<i8>Constructs a PrimitiveArray from an array data reference.
fn from(data: ArrayDataRef) -> Self[src]
fn from(data: ArrayDataRef) -> Selfimpl From<Vec<i16>> for PrimitiveArray<i16>[src]
impl From<Vec<i16>> for PrimitiveArray<i16>Constructs a primitive array from a vector. Should only be used for testing.
impl From<Vec<Option<i16>>> for PrimitiveArray<i16>[src]
impl From<Vec<Option<i16>>> for PrimitiveArray<i16>impl From<Arc<ArrayData>> for PrimitiveArray<i16>[src]
impl From<Arc<ArrayData>> for PrimitiveArray<i16>Constructs a PrimitiveArray from an array data reference.
fn from(data: ArrayDataRef) -> Self[src]
fn from(data: ArrayDataRef) -> Selfimpl From<Vec<i32>> for PrimitiveArray<i32>[src]
impl From<Vec<i32>> for PrimitiveArray<i32>Constructs a primitive array from a vector. Should only be used for testing.
impl From<Vec<Option<i32>>> for PrimitiveArray<i32>[src]
impl From<Vec<Option<i32>>> for PrimitiveArray<i32>impl From<Arc<ArrayData>> for PrimitiveArray<i32>[src]
impl From<Arc<ArrayData>> for PrimitiveArray<i32>Constructs a PrimitiveArray from an array data reference.
fn from(data: ArrayDataRef) -> Self[src]
fn from(data: ArrayDataRef) -> Selfimpl From<Vec<i64>> for PrimitiveArray<i64>[src]
impl From<Vec<i64>> for PrimitiveArray<i64>Constructs a primitive array from a vector. Should only be used for testing.
impl From<Vec<Option<i64>>> for PrimitiveArray<i64>[src]
impl From<Vec<Option<i64>>> for PrimitiveArray<i64>impl From<Arc<ArrayData>> for PrimitiveArray<i64>[src]
impl From<Arc<ArrayData>> for PrimitiveArray<i64>Constructs a PrimitiveArray from an array data reference.
fn from(data: ArrayDataRef) -> Self[src]
fn from(data: ArrayDataRef) -> Selfimpl From<Vec<f32>> for PrimitiveArray<f32>[src]
impl From<Vec<f32>> for PrimitiveArray<f32>Constructs a primitive array from a vector. Should only be used for testing.
impl From<Vec<Option<f32>>> for PrimitiveArray<f32>[src]
impl From<Vec<Option<f32>>> for PrimitiveArray<f32>impl From<Arc<ArrayData>> for PrimitiveArray<f32>[src]
impl From<Arc<ArrayData>> for PrimitiveArray<f32>Constructs a PrimitiveArray from an array data reference.
fn from(data: ArrayDataRef) -> Self[src]
fn from(data: ArrayDataRef) -> Selfimpl From<Vec<f64>> for PrimitiveArray<f64>[src]
impl From<Vec<f64>> for PrimitiveArray<f64>Constructs a primitive array from a vector. Should only be used for testing.
impl From<Vec<Option<f64>>> for PrimitiveArray<f64>[src]
impl From<Vec<Option<f64>>> for PrimitiveArray<f64>impl From<Arc<ArrayData>> for PrimitiveArray<f64>[src]
impl From<Arc<ArrayData>> for PrimitiveArray<f64>Constructs a PrimitiveArray from an array data reference.
fn from(data: ArrayDataRef) -> Self[src]
fn from(data: ArrayDataRef) -> Selfimpl From<Vec<bool>> for PrimitiveArray<bool>[src]
impl From<Vec<bool>> for PrimitiveArray<bool>Constructs a boolean array from a vector. Should only be used for testing.
impl From<Vec<Option<bool>>> for PrimitiveArray<bool>[src]
impl From<Vec<Option<bool>>> for PrimitiveArray<bool>impl From<Arc<ArrayData>> for PrimitiveArray<bool>[src]
impl From<Arc<ArrayData>> for PrimitiveArray<bool>Constructs a PrimitiveArray<bool> from an array data reference.
fn from(data: ArrayDataRef) -> Self[src]
fn from(data: ArrayDataRef) -> SelfAuto Trait Implementations
impl<T> Send for PrimitiveArray<T>
impl<T> Send for PrimitiveArray<T>impl<T> Sync for PrimitiveArray<T>
impl<T> Sync for PrimitiveArray<T>Blanket Implementations
impl<T> From for T[src]
impl<T> From for Timpl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>[src]
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId[src]
fn get_type_id(&self) -> TypeIdimpl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>[src]
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, fn borrow_mut(&mut self) -> &mut T[src]
fn borrow_mut(&mut self) -> &mut T