[−][src]Module arrow::buffer
Structs
| Buffer | Buffer is a contiguous memory region of fixed size and is aligned at a 64-byte boundary. Buffer is immutable. |
| MutableBuffer | Similar to |
| Buffer | Buffer is a contiguous memory region of fixed size and is aligned at a 64-byte boundary. Buffer is immutable. |
| MutableBuffer | Similar to |