[−][src]Struct arrow::buffer::MutableBuffer
Similar to Buffer, but is growable and can be mutated. A mutable buffer can be
converted into a immutable buffer via the freeze method.
Methods
impl MutableBuffer[src]
impl MutableBufferpub fn new(capacity: usize) -> Self[src]
pub fn new(capacity: usize) -> SelfAllocate a new mutable buffer with initial capacity to be capacity.
pub fn with_bitset(self, end: usize, val: bool) -> Self[src]
pub fn with_bitset(self, end: usize, val: bool) -> SelfSet the bits in the range of [0, end) to 0 (if val is false), or 1 (if val
is true). Also extend the length of this buffer to be end.
This is useful when one wants to clear (or set) the bits and then manipulate
the buffer directly (e.g., modifying the buffer by holding a mutable reference
from data_mut()).
pub fn set_null_bits(&mut self, start: usize, count: usize)[src]
pub fn set_null_bits(&mut self, start: usize, count: usize)Ensure that count bytes from start contain zero bits
This is used to initialize the bits in a buffer, however, it has no impact on the len
of the buffer and so can be used to initialize the memory region from len to capacity.
pub fn reserve(&mut self, capacity: usize) -> Result<usize>[src]
pub fn reserve(&mut self, capacity: usize) -> Result<usize>Ensures that this buffer has at least capacity slots in this buffer. This will
also ensure the new capacity will be a multiple of 64 bytes.
Returns the new capacity for this buffer.
pub fn resize(&mut self, new_len: usize) -> Result<()>[src]
pub fn resize(&mut self, new_len: usize) -> Result<()>Resizes the buffer so that the len will equal to the new_len.
If new_len is greater than len, the buffer's length is simply adjusted to be
the former, optionally extending the capacity. The data between len and
new_len will remain unchanged.
If new_len is less than len, the buffer will be truncated.
pub fn is_empty(&self) -> bool[src]
pub fn is_empty(&self) -> boolReturns whether this buffer is empty or not.
pub fn len(&self) -> usize[src]
pub fn len(&self) -> usizeReturns the length (the number of bytes written) in this buffer.
pub fn capacity(&self) -> usize[src]
pub fn capacity(&self) -> usizeReturns the total capacity in this buffer.
pub fn clear(&mut self)[src]
pub fn clear(&mut self)Clear all existing data from this buffer.
pub fn data(&self) -> &[u8][src]
pub fn data(&self) -> &[u8]Returns the data stored in this buffer as a slice.
pub fn data_mut(&mut self) -> &mut [u8][src]
pub fn data_mut(&mut self) -> &mut [u8]Returns the data stored in this buffer as a mutable slice.
pub fn raw_data(&self) -> *const u8[src]
pub fn raw_data(&self) -> *const u8Returns a raw pointer for this buffer.
Note that this should be used cautiously, and the returned pointer should not be stored anywhere, to avoid dangling pointers.
pub fn freeze(self) -> Buffer[src]
pub fn freeze(self) -> BufferFreezes this buffer and return an immutable version of it.