[−][src]Struct arrow::builder::PrimitiveArrayBuilder
Array builder for fixed-width primitive types
Methods
impl PrimitiveArrayBuilder<bool>[src]
impl PrimitiveArrayBuilder<bool>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a new primitive array builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the capacity of this builder measured in slots of type T
pub fn push(&mut self, v: bool) -> Result<()>[src]
pub fn push(&mut self, v: bool) -> Result<()>Pushes a value of type T into the builder
pub fn push_null(&mut self) -> Result<()>[src]
pub fn push_null(&mut self) -> Result<()>Pushes a null slot into the builder
pub fn push_option(&mut self, v: Option<bool>) -> Result<()>[src]
pub fn push_option(&mut self, v: Option<bool>) -> Result<()>Pushes an Option<T> into the builder
pub fn push_slice(&mut self, v: &[bool]) -> Result<()>[src]
pub fn push_slice(&mut self, v: &[bool]) -> Result<()>Pushes a slice of type T into the builder
impl PrimitiveArrayBuilder<u8>[src]
impl PrimitiveArrayBuilder<u8>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a new primitive array builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the capacity of this builder measured in slots of type T
pub fn push(&mut self, v: u8) -> Result<()>[src]
pub fn push(&mut self, v: u8) -> Result<()>Pushes a value of type T into the builder
pub fn push_null(&mut self) -> Result<()>[src]
pub fn push_null(&mut self) -> Result<()>Pushes a null slot into the builder
pub fn push_option(&mut self, v: Option<u8>) -> Result<()>[src]
pub fn push_option(&mut self, v: Option<u8>) -> Result<()>Pushes an Option<T> into the builder
pub fn push_slice(&mut self, v: &[u8]) -> Result<()>[src]
pub fn push_slice(&mut self, v: &[u8]) -> Result<()>Pushes a slice of type T into the builder
impl PrimitiveArrayBuilder<u16>[src]
impl PrimitiveArrayBuilder<u16>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a new primitive array builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the capacity of this builder measured in slots of type T
pub fn push(&mut self, v: u16) -> Result<()>[src]
pub fn push(&mut self, v: u16) -> Result<()>Pushes a value of type T into the builder
pub fn push_null(&mut self) -> Result<()>[src]
pub fn push_null(&mut self) -> Result<()>Pushes a null slot into the builder
pub fn push_option(&mut self, v: Option<u16>) -> Result<()>[src]
pub fn push_option(&mut self, v: Option<u16>) -> Result<()>Pushes an Option<T> into the builder
pub fn push_slice(&mut self, v: &[u16]) -> Result<()>[src]
pub fn push_slice(&mut self, v: &[u16]) -> Result<()>Pushes a slice of type T into the builder
impl PrimitiveArrayBuilder<u32>[src]
impl PrimitiveArrayBuilder<u32>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a new primitive array builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the capacity of this builder measured in slots of type T
pub fn push(&mut self, v: u32) -> Result<()>[src]
pub fn push(&mut self, v: u32) -> Result<()>Pushes a value of type T into the builder
pub fn push_null(&mut self) -> Result<()>[src]
pub fn push_null(&mut self) -> Result<()>Pushes a null slot into the builder
pub fn push_option(&mut self, v: Option<u32>) -> Result<()>[src]
pub fn push_option(&mut self, v: Option<u32>) -> Result<()>Pushes an Option<T> into the builder
pub fn push_slice(&mut self, v: &[u32]) -> Result<()>[src]
pub fn push_slice(&mut self, v: &[u32]) -> Result<()>Pushes a slice of type T into the builder
impl PrimitiveArrayBuilder<u64>[src]
impl PrimitiveArrayBuilder<u64>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a new primitive array builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the capacity of this builder measured in slots of type T
pub fn push(&mut self, v: u64) -> Result<()>[src]
pub fn push(&mut self, v: u64) -> Result<()>Pushes a value of type T into the builder
pub fn push_null(&mut self) -> Result<()>[src]
pub fn push_null(&mut self) -> Result<()>Pushes a null slot into the builder
pub fn push_option(&mut self, v: Option<u64>) -> Result<()>[src]
pub fn push_option(&mut self, v: Option<u64>) -> Result<()>Pushes an Option<T> into the builder
pub fn push_slice(&mut self, v: &[u64]) -> Result<()>[src]
pub fn push_slice(&mut self, v: &[u64]) -> Result<()>Pushes a slice of type T into the builder
impl PrimitiveArrayBuilder<i8>[src]
impl PrimitiveArrayBuilder<i8>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a new primitive array builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the capacity of this builder measured in slots of type T
pub fn push(&mut self, v: i8) -> Result<()>[src]
pub fn push(&mut self, v: i8) -> Result<()>Pushes a value of type T into the builder
pub fn push_null(&mut self) -> Result<()>[src]
pub fn push_null(&mut self) -> Result<()>Pushes a null slot into the builder
pub fn push_option(&mut self, v: Option<i8>) -> Result<()>[src]
pub fn push_option(&mut self, v: Option<i8>) -> Result<()>Pushes an Option<T> into the builder
pub fn push_slice(&mut self, v: &[i8]) -> Result<()>[src]
pub fn push_slice(&mut self, v: &[i8]) -> Result<()>Pushes a slice of type T into the builder
impl PrimitiveArrayBuilder<i16>[src]
impl PrimitiveArrayBuilder<i16>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a new primitive array builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the capacity of this builder measured in slots of type T
pub fn push(&mut self, v: i16) -> Result<()>[src]
pub fn push(&mut self, v: i16) -> Result<()>Pushes a value of type T into the builder
pub fn push_null(&mut self) -> Result<()>[src]
pub fn push_null(&mut self) -> Result<()>Pushes a null slot into the builder
pub fn push_option(&mut self, v: Option<i16>) -> Result<()>[src]
pub fn push_option(&mut self, v: Option<i16>) -> Result<()>Pushes an Option<T> into the builder
pub fn push_slice(&mut self, v: &[i16]) -> Result<()>[src]
pub fn push_slice(&mut self, v: &[i16]) -> Result<()>Pushes a slice of type T into the builder
impl PrimitiveArrayBuilder<i32>[src]
impl PrimitiveArrayBuilder<i32>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a new primitive array builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the capacity of this builder measured in slots of type T
pub fn push(&mut self, v: i32) -> Result<()>[src]
pub fn push(&mut self, v: i32) -> Result<()>Pushes a value of type T into the builder
pub fn push_null(&mut self) -> Result<()>[src]
pub fn push_null(&mut self) -> Result<()>Pushes a null slot into the builder
pub fn push_option(&mut self, v: Option<i32>) -> Result<()>[src]
pub fn push_option(&mut self, v: Option<i32>) -> Result<()>Pushes an Option<T> into the builder
pub fn push_slice(&mut self, v: &[i32]) -> Result<()>[src]
pub fn push_slice(&mut self, v: &[i32]) -> Result<()>Pushes a slice of type T into the builder
impl PrimitiveArrayBuilder<i64>[src]
impl PrimitiveArrayBuilder<i64>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a new primitive array builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the capacity of this builder measured in slots of type T
pub fn push(&mut self, v: i64) -> Result<()>[src]
pub fn push(&mut self, v: i64) -> Result<()>Pushes a value of type T into the builder
pub fn push_null(&mut self) -> Result<()>[src]
pub fn push_null(&mut self) -> Result<()>Pushes a null slot into the builder
pub fn push_option(&mut self, v: Option<i64>) -> Result<()>[src]
pub fn push_option(&mut self, v: Option<i64>) -> Result<()>Pushes an Option<T> into the builder
pub fn push_slice(&mut self, v: &[i64]) -> Result<()>[src]
pub fn push_slice(&mut self, v: &[i64]) -> Result<()>Pushes a slice of type T into the builder
impl PrimitiveArrayBuilder<f32>[src]
impl PrimitiveArrayBuilder<f32>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a new primitive array builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the capacity of this builder measured in slots of type T
pub fn push(&mut self, v: f32) -> Result<()>[src]
pub fn push(&mut self, v: f32) -> Result<()>Pushes a value of type T into the builder
pub fn push_null(&mut self) -> Result<()>[src]
pub fn push_null(&mut self) -> Result<()>Pushes a null slot into the builder
pub fn push_option(&mut self, v: Option<f32>) -> Result<()>[src]
pub fn push_option(&mut self, v: Option<f32>) -> Result<()>Pushes an Option<T> into the builder
pub fn push_slice(&mut self, v: &[f32]) -> Result<()>[src]
pub fn push_slice(&mut self, v: &[f32]) -> Result<()>Pushes a slice of type T into the builder
impl PrimitiveArrayBuilder<f64>[src]
impl PrimitiveArrayBuilder<f64>pub fn new(capacity: i64) -> Self[src]
pub fn new(capacity: i64) -> SelfCreates a new primitive array builder
pub fn capacity(&self) -> i64[src]
pub fn capacity(&self) -> i64Returns the capacity of this builder measured in slots of type T
pub fn push(&mut self, v: f64) -> Result<()>[src]
pub fn push(&mut self, v: f64) -> Result<()>Pushes a value of type T into the builder
pub fn push_null(&mut self) -> Result<()>[src]
pub fn push_null(&mut self) -> Result<()>Pushes a null slot into the builder
pub fn push_option(&mut self, v: Option<f64>) -> Result<()>[src]
pub fn push_option(&mut self, v: Option<f64>) -> Result<()>Pushes an Option<T> into the builder
pub fn push_slice(&mut self, v: &[f64]) -> Result<()>[src]
pub fn push_slice(&mut self, v: &[f64]) -> Result<()>Pushes a slice of type T into the builder