Function product_checked
pub fn product_checked<T>(
array: &PrimitiveArray<T>,
) -> Result<Option<<T as ArrowPrimitiveType>::Native>, ArrowError>where
T: ArrowNumericType,Expand description
Returns the product of values in the primitive array.
Returns Ok(None) if the array is empty or only contains null values.
This detects overflow and returns an Err for that. For an non-overflow-checking variant,
use product instead.