Function concat_elements_bytes
pub fn concat_elements_bytes<T>(
left: &GenericByteArray<T>,
right: &GenericByteArray<T>,
) -> Result<GenericByteArray<T>, ArrowError>where
T: ByteArrayType,Expand description
Returns the elementwise concatenation of a GenericByteArray.
Errors
Returns an error if the arrays have different lengths, or if the concatenated data is too long for the offset type.