Function concat_elements_fixed_size_binary
pub fn concat_elements_fixed_size_binary(
left: &FixedSizeBinaryArray,
right: &FixedSizeBinaryArray,
) -> Result<FixedSizeBinaryArray, ArrowError>Expand description
Returns the elementwise concatenation of a FixedSizeBinaryArray.
The result has value_length = left.value_length() + right.value_length().
An index is null if either input is null at that position.
An error will be returned if left and right have different lengths.