Function concat_elements_utf8_many
pub fn concat_elements_utf8_many<Offset>(
arrays: &[&GenericByteArray<GenericStringType<Offset>>],
) -> Result<GenericByteArray<GenericStringType<Offset>>, ArrowError>where
Offset: OffsetSizeTrait,Expand description
Returns the elementwise concatenation of StringArray.
e.g:
["a", "b"] + [None, "c"] + [None, "d"] = [None, "bcd"]An error will be returned if the StringArray are of different lengths
Errors
Returns an error if the arrays have different lengths, or if the concatenated data is too long for the offset type.