[−][src]Module arrow::datatypes
Defines the data-types of Arrow arrays.
For an overview of the terminology used within the arrow project and more general information regarding data-types and memory layouts see here.
Structs
| BooleanType | |
| Field | Contains the meta-data for a single relative type. |
| Float32Type | |
| Float64Type | |
| Int8Type | |
| Int16Type | |
| Int32Type | |
| Int64Type | |
| Schema | Describes the meta-data of an ordered sequence of relative types. |
| UInt8Type | |
| UInt16Type | |
| UInt32Type | |
| UInt64Type |
Enums
| DataType | The possible relative types that are supported. |
Traits
| ArrowNativeType | |
| ArrowNumericType | A subtype of primitive type that represents numeric values. |
| ArrowPrimitiveType | Trait indicating a primitive fixed-width type (bool, ints and floats). |
| ToByteSlice | Allows conversion from supported Arrow types to a byte slice. |