[−][src]Struct arrow::datatypes::Schema
Describes the meta-data of an ordered sequence of relative types.
Note that this information is only part of the meta-data and not part of the physical memory layout.
Methods
impl Schema[src]
impl Schemapub fn empty() -> Self[src]
pub fn empty() -> SelfCreates an empty Schema
pub fn new(fields: Vec<Field>) -> Self[src]
pub fn new(fields: Vec<Field>) -> SelfCreates a new Schema from a sequence of Field values
Example
let field_a = Field::new("a", DataType::Int64, false); let field_b = Field::new("b", DataType::Boolean, false); let schema = Schema::new(vec![field_a, field_b]);
pub fn fields(&self) -> &Vec<Field>[src]
pub fn fields(&self) -> &Vec<Field>Returns an immutable reference of the vector of Field instances
pub fn field(&self, i: usize) -> &Field[src]
pub fn field(&self, i: usize) -> &FieldReturns an immutable reference of a specific Field instance selected using an offset
within the internal fields vector
pub fn column_with_name(&self, name: &str) -> Option<(usize, &Field)>[src]
pub fn column_with_name(&self, name: &str) -> Option<(usize, &Field)>Look up a column by name and return a immutable reference to the column along with it's index