Enum arrow::error::ArrowError [−][src]
pub enum ArrowError {
Show variants
NotYetImplemented(String),
ExternalError(Box<dyn Error + Send + Sync>),
CastError(String),
MemoryError(String),
ParseError(String),
SchemaError(String),
ComputeError(String),
DivideByZero,
CsvError(String),
JsonError(String),
IoError(String),
InvalidArgumentError(String),
ParquetError(String),
CDataInterface(String),
DictionaryKeyOverflowError,
}Expand description
Many different operations in the arrow crate return this error type.
Variants
NotYetImplemented(String)Returned when functionality is not yet available.
CastError(String)MemoryError(String)ParseError(String)SchemaError(String)ComputeError(String)CsvError(String)JsonError(String)IoError(String)InvalidArgumentError(String)ParquetError(String)CDataInterface(String)Error during import or export to/from the C Data Interface
Implementations
impl ArrowError[src]
impl ArrowError[src]Trait Implementations
impl Debug for ArrowError[src]
impl Debug for ArrowError[src]impl Display for ArrowError[src]
impl Display for ArrowError[src]impl Error for ArrowError[src]
impl Error for ArrowError[src]fn source(&self) -> Option<&(dyn Error + 'static)>1.30.0[src]
fn source(&self) -> Option<&(dyn Error + 'static)>1.30.0[src]The lower-level source of this error, if any. Read more
fn backtrace(&self) -> Option<&Backtrace>[src]
fn backtrace(&self) -> Option<&Backtrace>[src]🔬 This is a nightly-only experimental API. (
backtrace)Returns a stack backtrace, if available, of where this error occurred. Read more
fn description(&self) -> &str1.0.0[src]
fn description(&self) -> &str1.0.0[src]👎 Deprecated since 1.42.0:
use the Display impl or to_string()
impl From<FromUtf8Error> for ArrowError[src]
impl From<FromUtf8Error> for ArrowError[src]fn from(error: FromUtf8Error) -> Self[src]
fn from(error: FromUtf8Error) -> Self[src]Performs the conversion.
impl<W: Write> From<IntoInnerError<W>> for ArrowError[src]
impl<W: Write> From<IntoInnerError<W>> for ArrowError[src]fn from(error: IntoInnerError<W>) -> Self[src]
fn from(error: IntoInnerError<W>) -> Self[src]Performs the conversion.